Lines

Struct Lines 

pub struct Lines<S>(/* private fields */);
A text buffer and metadata about lines.

This is internally reference-counted and thus cheap to clone.

Implementations

Source

impl<T> Lines<T>
where T: AsRef<str>,

pub fn new(text: T) -> Lines<T>

Create from the text buffer and compute the line metadata.

pub fn text(&self) -> &str

The text as a string slice.

pub fn len_bytes(&self) -> usize

Get the length of the file in UTF-8 encoded bytes.

pub fn len_utf16(&self) -> usize

Get the length of the file in UTF-16 code units.

pub fn len_lines(&self) -> usize

Get the length of the file in lines.

pub fn byte_to_utf16(&self, byte_idx: usize) -> Option<usize>

Return the index of the UTF-16 code unit at the byte index.

pub fn byte_to_line(&self, byte_idx: usize) -> Option<usize>

Return the index of the line that contains the given byte index.

pub fn byte_to_column(&self, byte_idx: usize) -> Option<usize>

Return the index of the column at the byte index.

The column is defined as the number of characters in the line before the byte index.

pub fn byte_to_line_column(&self, byte_idx: usize) -> Option<(usize, usize)>

Return the index of the line and column at the byte index.

pub fn utf16_to_byte(&self, utf16_idx: usize) -> Option<usize>

Return the byte index at the UTF-16 code unit.

pub fn line_to_byte(&self, line_idx: usize) -> Option<usize>

Return the byte position at which the given line starts.

pub fn line_to_range(&self, line_idx: usize) -> Option<Range<usize>>

Return the range which encloses the given line.

pub fn line_column_to_byte( &self, line_idx: usize, column_idx: usize, ) -> Option<usize>

Return the byte index of the given (line, column) pair.

The column defines the number of characters to go beyond the start of the line.

Source

impl Lines<String>

pub fn replace(&mut self, new: &str) -> bool

Fully replace the source text.

This performs a naive (suffix/prefix-based) diff of the old and new text to produce the smallest single edit that transforms old into new and then calls edit with it.

Returns whether any changes were made.

pub fn replacement_range(&self, new: &str) -> Option<(usize, usize)>

Returns the common prefix and suffix lengths. Returns None if the old and new strings are equal.

pub fn edit(&mut self, replace: Range<usize>, with: &str)

Edit the source file by replacing the given range.

Returns the range in the new source that was ultimately reparsed.

The method panics if the replace range is out of bounds.