pub struct SyntaxNode { /* private fields */ }Expand description
A node in the untyped syntax tree.
Implementations
Sourceimpl SyntaxNode
impl SyntaxNode
Sourceimpl SyntaxNode
impl SyntaxNode
Sourcepub fn leaf(kind: SyntaxKind, text: impl Into<EcoString>) -> SyntaxNode
pub fn leaf(kind: SyntaxKind, text: impl Into<EcoString>) -> SyntaxNode
Create a new leaf node.
Sourcepub fn inner(kind: SyntaxKind, children: Vec<SyntaxNode>) -> SyntaxNode
pub fn inner(kind: SyntaxKind, children: Vec<SyntaxNode>) -> SyntaxNode
Create a new inner node with children.
Sourcepub fn error(
message: impl Into<EcoString>,
text: impl Into<EcoString>,
) -> SyntaxNode
pub fn error( message: impl Into<EcoString>, text: impl Into<EcoString>, ) -> SyntaxNode
Create a new error node with a user-presentable message for the given text. Note that the message is the first argument, and the text causing the error is the second argument.
Sourcepub fn warn(&mut self, message: impl Into<EcoString>)
pub fn warn(&mut self, message: impl Into<EcoString>)
Add a warning message to an existing node.
Sourcepub fn warn_at(&mut self, _: Range<usize>, message: impl Into<EcoString>)
pub fn warn_at(&mut self, _: Range<usize>, message: impl Into<EcoString>)
Add a warning around this node at a particular sub-range of the node’s text. Panics if the range is empty or exceeds the length of the wrapped text.
Sourcepub fn hint(&mut self, hint: impl Into<EcoString>)
pub fn hint(&mut self, hint: impl Into<EcoString>)
Add a user-presentable hint to an existing error or warning. Panics if this is not an error or warning.
Sourcepub fn hint_at(&mut self, _: Range<usize>, hint: impl Into<EcoString>)
pub fn hint_at(&mut self, _: Range<usize>, hint: impl Into<EcoString>)
Add a user-presentable hint to an existing error or warning at a sub-range of the text. Panics if the range is empty or exceeds the length of the wrapped text. Panics if this is not an error or warning node.
Sourcepub fn with_hints(
self,
new_hints: impl IntoIterator<Item = EcoString>,
) -> SyntaxNode
pub fn with_hints( self, new_hints: impl IntoIterator<Item = EcoString>, ) -> SyntaxNode
Add multiple hints while building an error or warning. Panics if this is not an error or warning.
Sourcepub const fn placeholder(kind: SyntaxKind) -> SyntaxNode
pub const fn placeholder(kind: SyntaxKind) -> SyntaxNode
Create a dummy node of the given kind.
Panics if kind is SyntaxKind::Error.
Sourcepub fn kind(&self) -> SyntaxKind
pub fn kind(&self) -> SyntaxKind
The type of the node.
Sourcepub fn leaf_text(&self) -> &EcoString
pub fn leaf_text(&self) -> &EcoString
The text of the node if it is a leaf or error node.
Returns the empty string if this is an inner node.
Sourcepub fn full_text(&self) -> EcoString
pub fn full_text(&self) -> EcoString
Clone the full text from the node. If this is an inner node, it will traverse the tree to build the text which may be expensive.
Sourcepub fn children(&self) -> Iter<'_, SyntaxNode>
pub fn children(&self) -> Iter<'_, SyntaxNode>
The node’s children.
Sourcepub fn diagnosis(&self) -> Diagnosis
pub fn diagnosis(&self) -> Diagnosis
Whether the node has diagnostic errors and/or warnings in it or its
children. Diagnosis has public fields, so you can write
node.diagnosis().errors to determine if a node is erroneous.
This can be used to determine whether Self::errors_and_warnings will
return an empty vector without traversing the tree if it will not.
Sourcepub fn errors_and_warnings(
&self,
) -> (Vec<SyntaxDiagnostic>, Vec<SyntaxDiagnostic>)
pub fn errors_and_warnings( &self, ) -> (Vec<SyntaxDiagnostic>, Vec<SyntaxDiagnostic>)
The error and warning diagnostics for this node and its descendants.
Sourcepub fn synthesize(&mut self, span: Span)
pub fn synthesize(&mut self, span: Span)
Set a synthetic span for the node and all its descendants.
Sourcepub fn synthesize_mapped(
&mut self,
id: FileId,
mapper: &RangeMapper,
) -> Result<(), EcoString>
pub fn synthesize_mapped( &mut self, id: FileId, mapper: &RangeMapper, ) -> Result<(), EcoString>
Set a raw range span for each node.
The range is determined by mapping the node’s ranges through the given
mapper.
Returns an error with the mapper’s length if it was shorter than the length of the source text.
Sourcepub fn spanless_eq(&self, other: &SyntaxNode) -> bool
pub fn spanless_eq(&self, other: &SyntaxNode) -> bool
Whether the two syntax nodes are the same apart from spans.