pub enum ProcessColor {
Luma(Alpha<Luma, f32>),
Oklab(Alpha<Oklab, f32>),
Oklch(Alpha<Oklch, f32>),
Rgb(Alpha<Rgb, f32>),
LinearRgb(Alpha<Rgb<Linear<Srgb>>, f32>),
Cmyk(Cmyk),
Hsl(Alpha<Hsl, f32>),
Hsv(Alpha<Hsv, f32>),
}Expand description
Colors with a well-defined color space.
Variants
Luma(Alpha<Luma, f32>)
A 32-bit luma color.
Oklab(Alpha<Oklab, f32>)
A 32-bit L*a*b* color in the Oklab color space.
Oklch(Alpha<Oklch, f32>)
A 32-bit LCh color in the Oklab color space.
Rgb(Alpha<Rgb, f32>)
A 32-bit RGB color.
LinearRgb(Alpha<Rgb<Linear<Srgb>>, f32>)
A 32-bit linear RGB color.
Cmyk(Cmyk)
A 32-bit CMYK color.
Hsl(Alpha<Hsl, f32>)
A 32-bit HSL color.
Hsv(Alpha<Hsv, f32>)
A 32-bit HSV color.
Implementations
Sourceimpl ProcessColor
impl ProcessColor
Sourcepub fn components(self, alpha: bool) -> Array
pub fn components(self, alpha: bool) -> Array
Extracts the components of this color.
Sourcepub fn space(self) -> ProcessColorSpace
pub fn space(self) -> ProcessColorSpace
Returns the constructor function for this color’s space.
Sourcepub fn lighten(self, factor: Ratio) -> ProcessColor
pub fn lighten(self, factor: Ratio) -> ProcessColor
Lightens a color by a given factor.
Sourcepub fn darken(self, factor: Ratio) -> ProcessColor
pub fn darken(self, factor: Ratio) -> ProcessColor
Darkens a color by a given factor.
Sourcepub fn saturate(
self,
span: Span,
factor: Ratio,
) -> Result<ProcessColor, EcoVec<SourceDiagnostic>>
pub fn saturate( self, span: Span, factor: Ratio, ) -> Result<ProcessColor, EcoVec<SourceDiagnostic>>
Increases the saturation of a color by a given factor.
Sourcepub fn desaturate(
self,
span: Span,
factor: Ratio,
) -> Result<ProcessColor, EcoVec<SourceDiagnostic>>
pub fn desaturate( self, span: Span, factor: Ratio, ) -> Result<ProcessColor, EcoVec<SourceDiagnostic>>
Decreases the saturation of a color by a given factor.
Sourcepub fn negate(self, space: ProcessColorSpace) -> ProcessColor
pub fn negate(self, space: ProcessColorSpace) -> ProcessColor
Produces the complementary color using a provided color space.
Sourcepub fn from_u8(r: u8, g: u8, b: u8, a: u8) -> ProcessColor
pub fn from_u8(r: u8, g: u8, b: u8, a: u8) -> ProcessColor
Construct a new RGBA color from 8-bit values.
Sourcepub fn from_u32(color: u32) -> ProcessColor
pub fn from_u32(color: u32) -> ProcessColor
Converts a 32-bit integer to an RGBA color.
Sourcepub fn with_alpha(self, alpha: f32) -> ProcessColor
pub fn with_alpha(self, alpha: f32) -> ProcessColor
Sets the alpha channel of the color, if it has one.
Sourcepub fn to_vec4_u8(&self) -> [u8; 4]
pub fn to_vec4_u8(&self) -> [u8; 4]
Converts the color to a vec of four u8s.
pub fn to_space(&self, space: ProcessColorSpace) -> ProcessColor
pub fn to_luma(self) -> Alpha<Luma, f32>
pub fn to_oklab(self) -> Alpha<Oklab, f32>
pub fn to_oklch(self) -> Alpha<Oklch, f32>
pub fn to_rgb(self) -> Alpha<Rgb, f32>
pub fn to_linear_rgb(self) -> Alpha<Rgb<Linear<Srgb>>, f32>
pub fn to_cmyk(self) -> Cmyk
pub fn to_hsl(self) -> Alpha<Hsl, f32>
pub fn to_hsv(self) -> Alpha<Hsv, f32>